<!--StacksImageList Carousel-->

<div class="stacks-module list-carousel stacks-image stacks-image-list-carousel grid">
    {% if self.title %}<h2 class="module-title">{{ self.title }}</h2>{% endif %}
    <div class="grid-block carousel">
        {% for item in self.list %}
            <div class="item">
                {{ item }}
            </div>
        {% endfor %}
    </div>
</div>
