.stacks-image-full-screen-viewer{
  position:fixed;
  width: 100%;
  height: 100%;
  top: 0px;
  left: 0px;

  .stacks-image-full-screen-viewer-background{
    background-color: #000;
    opacity: 0.8;
    width: 100%;
    height: 100%;
    top: 0px;
    left: 0px;
    position: absolute;
  }

  .stacks-image-full-screen-image{
    width: auto;
    height: auto;
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    margin: auto;

  }
}

.list-gallery {
  img.thumbnail {
    cursor:pointer;
  }
}
