<!--StacksImageList 3-up Grid-->

<div class="stacks-module list-3up stacks-image stacks-image-list-3up grid {{ addl_classes }}">
    {% if self.title %}<h2 class="module-title">{{ self.title }}</h2>{% endif %}
    {% for item in self.list %}
    {% if forloop.first or forloop.counter0|divisibleby:'3' %}
    <div class="media-row grid-row">
    {% endif %}
        <div class="grid-3up grid-block
            {% if forloop.first or forloop.counter0|divisibleby:'3' %}first-in-row{% endif %} {% if forloop.counter|divisibleby:'3' %}last-in-row{% endif %}">
            <div class="grid-block-inner">
                {{ item }}
            </div>
        </div>
    {% if forloop.last or forloop.counter|divisibleby:'3' %}
    </div>
    {% endif %}
    {% endfor %}
</div>
